@@ -136,20 +136,43 @@ def get_varying_probe(shared_probe, eigen_probe=None, weights=None):
         return shared_probe.copy()
 
 
-def constrain_variable_probe(variable_probe, weights):
-    """Add the following constraints to variable probe weights
+def _constrain_variable_probe1(variable_probe, weights):
+    """Help use the thread pool with constrain_variable_probe"""
 
-    1. Remove outliars from weights
-    2. Enforce orthogonality once per epoch
+    # Normalize variable probes
+    vnorm = tike.linalg.mnorm(variable_probe, axis=(-2, -1), keepdims=True)
+    variable_probe /= vnorm
+    probes_with_modes = variable_probe.shape[-3]
+    weights[..., 1:, :probes_with_modes] *= vnorm[..., 0, 0]
 
-    """
-    logger.info('Orthogonalize variable probes')
+    # Orthogonalize variable probes
     variable_probe = tike.linalg.orthogonalize_gs(
         variable_probe,
-        axis=(-3, -2, -1),
+        axis=(-2, -1),
+        N=-4,
     )
 
-    logger.info('Remove outliars from variable probe weights')
+    # Compute probe energy in order to sort probes by energy
+    power = tike.linalg.norm(
+        weights[..., 1:, :probes_with_modes],
+        keepdims=True,
+        axis=-3,
+    )**2
+
+    return variable_probe, weights, power
+
+
+def _constrain_variable_probe2(variable_probe, weights, power):
+    """Help use the thread pool with constrain_variable_probe"""
+
+    # Sort the probes by energy
+    probes_with_modes = variable_probe.shape[-3]
+    for i in range(probes_with_modes):
+        sorted = np.argsort(-power[..., i].flatten())
+        weights[..., 1:, i] = weights[..., 1 + sorted, i]
+        variable_probe[..., :, i, :, :] = variable_probe[..., sorted, i, :, :]
+
+    # Remove outliars from variable probe weights
     aevol = cp.abs(weights)
     weights = cp.minimum(
         aevol,
@@ -161,7 +184,38 @@ def constrain_variable_probe(variable_probe, weights):
         ).astype(weights.dtype),
     ) * cp.sign(weights)
 
-    # TODO: Smooth the weights as a function of the frame index.
+    return variable_probe, weights
+
+
+def constrain_variable_probe(comm, variable_probe, weights):
+    """Add the following constraints to variable probe weights
+
+    1. Remove outliars from weights
+    2. Enforce orthogonality once per epoch
+    3. Sort the variable probes by their total energy
+    4. Normalize the variable probes so the energy is contained in the weight
+
+    """
+    # TODO: No smoothing of variable probe weights yet because the weights are
+    # not stored consecutively in device memory. Smoothing would require either
+    # sorting and synchronizing the weights with the host OR implementing
+    # smoothing of non-gridded data with splines using device-local data only.
+
+    variable_probe, weights, power = zip(*comm.pool.map(
+        _constrain_variable_probe1,
+        variable_probe,
+        weights,
+    ))
+
+    # reduce power by sum across all devices
+    power = comm.pool.allreduce(power)
+
+    variable_probe, weights = (list(a) for a in zip(*comm.pool.map(
+        _constrain_variable_probe2,
+        variable_probe,
+        weights,
+        power,
+    )))
 
     return variable_probe, weights
 
@@ -479,7 +533,12 @@ def orthogonalize_eig(x):
     # order, so we just reverse the order of modes to have them sorted in
     # descending order.
     vectors = vectors[..., ::-1].swapaxes(-1, -2)
-    return (vectors @ x.reshape(*x.shape[:-2], -1)).reshape(*x.shape)
+    result = (vectors @ x.reshape(*x.shape[:-2], -1)).reshape(*x.shape)
+    assert np.all(
+        np.diff(tike.linalg.norm(result, axis=(-2, -1), keepdims=False),
+                axis=-1) <= 0
+    ), "Power of the orthogonalized probes should be monotonically decreasing!"
+    return result
 
 
 def gaussian(size, rin=0.8, rout=1.0):
